==> Lock5Data_2.8.tar.gz: Lock5Data/man/USStates1e.Rd <==
\name{USStates1e}
\alias{USStates1e}
\docType{data}
\title{
US State Data
}
\description{
Various data for all 50 US States
}
%\usage{data(USStates)}
\format{
  A dataset with 50 observations on the following 17 variables.
  \tabular{rl}{
    \code{State} \tab {Name of state} \cr
    \code{HouseholdIncome} \tab {Mean household income (in dollars)} \cr
    \code{IQ} \tab {Mean IQ score of residents} \cr
    \code{McCainVote} \tab {Percentage of votes for John McCain in 2008 Presidential election} \cr
    \code{Region} \tab {Area of the country: \code{MW}=Midwest, \code{NE}=Northeast, \code{S}=South, or \code{W}=West} \cr
    \code{ObamaMcCain} \tab {Which 2008 Presidential candidate won state?  \code{M}=McCain or \code{O}=Obama} \cr
    \code{Population} \tab {Number of residents (in millions)} \cr
    \code{EighthGradeMath} \tab {Average score NAEP mathematics for 8th-grade students } \cr
    \code{HighSchool} \tab {Percentage of high school graduates} \cr
    \code{GSP} \tab {Gross State Product (dollars per capita)} \cr
    \code{FiveVegetables} \tab {Percentage of residents who eat at least five servings of fruits/vegetables per day} \cr
    \code{Smokers} \tab {Percentage of residents who smoke} \cr
    \code{PhysicalActivity} \tab {Percentage of residents who have competed in a physical activity in past month} \cr
    \code{Obese} \tab {Percentage of residents classified as obese} \cr
    \code{College} \tab {Percentage of residents with college degrees} \cr
    \code{NonWhite} \tab {Percentage of residents who are not white} \cr
    \code{HeavyDrinkers} \tab {Percentage of residents who drink heavily} \cr
  }
}
\details{
Information from each of the 50 states of the United States. \cr
** From 1e - dataset has been updated for 2e **
}
\source{
Various online sources, mostly at \emph{www.census.gov}
}

\keyword{datasets}

==> Lock5Data_3.0.0.tar.gz: Lock5Data/man/USStates1e.Rd <==
\name{USStates1e}
\alias{USStates1e}
\docType{data}
\title{
US State Data - 1e
}
\description{
Various data for all 50 US States
}
%\usage{data(USStates)}
\format{
  A dataset with 50 observations on the following 17 variables.
  \tabular{rl}{
    \code{State} \tab {Name of state} \cr
    \code{HouseholdIncome} \tab {Mean household income (in dollars)} \cr
    \code{IQ} \tab {Mean IQ score of residents} \cr
    \code{McCainVote} \tab {Percentage of votes for John McCain in 2008 Presidential election} \cr
    \code{Region} \tab {Area of the country: \code{MW}=Midwest, \code{NE}=Northeast, \code{S}=South, or \code{W}=West} \cr
    \code{ObamaMcCain} \tab {Which 2008 Presidential candidate won state?  \code{M}=McCain or \code{O}=Obama} \cr
    \code{Population} \tab {Number of residents (in millions)} \cr
    \code{EighthGradeMath} \tab {Average score NAEP mathematics for 8th-grade students } \cr
    \code{HighSchool} \tab {Percentage of high school graduates} \cr
    \code{GSP} \tab {Gross State Product (dollars per capita)} \cr
    \code{FiveVegetables} \tab {Percentage of residents who eat at least five servings of fruits/vegetables per day} \cr
    \code{Smokers} \tab {Percentage of residents who smoke} \cr
    \code{PhysicalActivity} \tab {Percentage of residents who have competed in a physical activity in past month} \cr
    \code{Obese} \tab {Percentage of residents classified as obese} \cr
    \code{College} \tab {Percentage of residents with college degrees} \cr
    \code{NonWhite} \tab {Percentage of residents who are not white} \cr
    \code{HeavyDrinkers} \tab {Percentage of residents who drink heavily} \cr
  }
}
\details{
Information from each of the 50 states of the United States. \cr
** From 1e - dataset has been updated for 2e and 3e **
}
\source{
Various online sources, mostly at \emph{www.census.gov}
}

\keyword{datasets}
